package com.cultural.heritage.model.dto.advanceOrder;

import com.cultural.heritage.common.PageRequest;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;


@Data
@EqualsAndHashCode(callSuper = true)
@Schema(description = "预约订单查询请求体", requiredProperties = {"id", "type", "minDeposit", "maxDeposit", "startTime", "endTime", "orderStatus"})
public class AdvanceOrderQueryRequest extends PageRequest implements Serializable {

    /**
     * 写真预约订单id
     */
    @Schema(description = "写真预约订单id", example = "2")
    private Long id;


    /**
     * 预约类别
     */
    @Schema(description = "预约类别", example = "整套约拍")
    private String type;


    /**
     * 最小定金
     */
    @Schema(description = "最小定金", example = "80")
    private BigDecimal minDeposit;


    /**
     * 最大定金
     */
    @Schema(description = "最大定金", example = "200")
    private BigDecimal maxDeposit;


    /**
     * 预约日期左区间
     */
    @Schema(description = "预约日期左区间", example = "2024-11-10")
    private String startTime;


    /**
     * 预约日期右区间
     */
    @Schema(description = "预约日期右区间", example = "2024-11-18")
    private String endTime;


    /**
     * 订单状态
     */
    @Schema(description = "订单状态", example = "待消费")
    private String orderStatus;


    /**
     * 订单创建时间左区间
     */
    @Schema(description = "订单创建时间左区间", example = "2024-11-19 15:00:00")
    private String createLeftTime;



    /**
     * 订单创建时间右区间
     */
    @Schema(description = "订单创建时间右区间", example = "2024-11-20 13:00:00")
    private String createRightTime;



    @Serial
    private static final long serialVersionUID = 1L;
}
